#!/usr/bin/env python
import sys
import time
import tkinter.messagebox
import eel
from loguru import logger

from controllers.ControllerADC import ControllerADC
from controllers.ControllerChromium import ControllerChromium
from models.LogSeverity import LogSeverity

logger.add(sys.stdout, level='DEBUG', format="<g>{time}</> | <r>{level}</> | <lvl>{message}</>")
logger.add('logs/{time:YYYY-MM-DD}.log', level='DEBUG', rotation='00:00', retention='10 days')
logger.info('started')


@eel.expose
def update_flight_plan_dict(flight_plan_json):
    return ControllerChromium.instance().update_flight_plan_dict(flight_plan_json)

@eel.expose
def update_view_settings_json(view_settings_json):
    return ControllerChromium.instance().update_view_settings_json(view_settings_json)

@eel.expose
def update_pois_repeat_count(repeat_count):
    return ControllerChromium.instance().update_pois_repeat_count(repeat_count)

@eel.expose
def update_pois_delay_before_execution_sec(delay_sec):
    return ControllerChromium.instance().update_pois_delay_before_execution_sec(delay_sec)

@eel.expose
def start_executing_flight_plan():
    return ControllerChromium.instance().start_executing_flight_plan()

@eel.expose
def initialize():
    return ControllerChromium.instance().update_state_frontend()

@eel.expose
def open_filepath_txt():
    return ControllerChromium.instance().open_filepath_txt()

@eel.expose
def open_filepath_ply():
    return ControllerChromium.instance().open_filepath_ply()

@eel.expose
def load_ply_and_txt():
    return ControllerChromium.instance().load_ply_and_txt()

@eel.expose
def save_project():
    return ControllerChromium.instance().save_project()

@eel.expose
def save_as_project():
    return ControllerChromium.instance().save_as_project()

@eel.expose
def open_project():
    return ControllerChromium.instance().open_project()

@eel.expose
def adc_clear_map():
    # Dummy function added in Version 6 and not yet implemented
    ControllerChromium.instance().show_message_box('Info', 'This function is not implemented yet.')
    return False

@eel.expose
def add_log(
    severity: str,
    message: str
):
    timestamp_unix = int(time.time())
    severity = LogSeverity(severity)
    ControllerChromium.instance().add_log(timestamp_unix, 'UI', severity, message)

@eel.expose
def save_poi(poi_name, x, y, poi_uuid):
    return ControllerChromium.instance().save_poi(poi_name, x, y, poi_uuid)

@eel.expose
def change_poi(uuid, x, y):
    return ControllerChromium.instance().change_poi(uuid, x, y)

@eel.expose
def rename_poi(poi_name_before, poi_name_after):
    return ControllerChromium.instance().rename_poi(poi_name_before, poi_name_after)

@eel.expose
def change_pois_order(uuids_order):
    return ControllerChromium.instance().change_pois_order(uuids_order)

@eel.expose
def delete_poi(uuid):
    return ControllerChromium.instance().delete_poi(uuid)

@eel.expose
def adc_take_off():
    return ControllerADC.instance().take_off()

@eel.expose
def adc_land():
    return ControllerADC.instance().land()

@eel.expose
def adc_stop():
    return ControllerADC.instance().stop()

@eel.expose
def clear_all_poi():
    return ControllerChromium.instance().clear_all_poi()

@eel.expose
def adc_fly_to_poi(poi_name, x, y):
    x, y = ControllerChromium.instance().convert_x_y_to_original(x, y)
    return ControllerADC.instance().fly_to_poi(
        x, y, z=0, w=0, name_poi=poi_name
    )

@eel.expose
def adc_yaw(degrees):
    return ControllerADC.instance().yaw(degrees)

@eel.expose
def adc_reset_rovio():
    return ControllerADC.instance().reset_rovio()

@eel.expose
def set_enabled_poi(uuid, enabled):
    return ControllerChromium.instance().set_enabled_poi(uuid, enabled)

# initialize drone data
ControllerADC.instance()

eel.start(
    'index.html',
    port=8880,
    size=(ControllerChromium.instance().screen_width, ControllerChromium.instance().screen_height),
    position=(0, 0),
    js_result_timeout=0
)
