
class ComponentMenu extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      isOpenFile: false,
      anchorEl: null
    }

    document.onkeydown = (e) => {
      try {
        e = e || window.event;
        if (e.ctrlKey || e.metaKey) {
          let c = e.which || e.keyCode;
          switch (c) {
            case 79:// Ctrl+O
              e.preventDefault();
              e.stopPropagation();
              if(e.shiftKey) {
                this.onOpenPLYandTXT();
              } else {
                this.onOpenProject();
              }
              break;
            case 83:// Ctrl+S
              e.preventDefault();
              e.stopPropagation();
              if(e.shiftKey) {
                this.onSaveAsProject();
              } else {
                this.onSaveProject();
              }
              break;
          }
        }
      } catch (e) {
        console.error(e);
      }
    };
  }

  onSaveProject = async () => {
    this.setState({isOpenFile : false});
    let result = await eel.save_project()();
    if(result) {
      alert(result);
    } else {
      alert("Project saved successfully");
    }
  }

  onSaveAsProject = async () => {
    this.setState({isOpenFile : false});
    let result = await eel.save_as_project()();
    if(result) {
      alert(result);
    } else {
      alert("Project saved successfully");
    }
  }

  onOpenProject = async () => {
    this.setState({isOpenFile : false});
    let result = await eel.open_project()();
    if(result) {
      alert(result);
    } else {
      this.resetMapSize();
    }
  }

  onOpenPLYandTXT = () => {
    this.setState({isOpenFile : false});
    this.props.onDialogLoadPLYandTXT();
  }

  resetMapSize = () => {
    $('a[data-val="auto"]').trigger("click");
  }

  render = () => {
    return (
    <div style={{position : "relative"}}>
      <Button
        aria-controls={this.state.isOpenFile ? 'demo-customized-menu' : undefined}
        aria-haspopup="true"
        aria-expanded={this.state.isOpenFile ? 'true' : undefined}
        variant="text"
        disableElevation
        onClick={(event)=> {
          this.setState({
            isOpenFile : !this.state.isOpenFile,
            anchorEl: event.currentTarget
          });
        }}
      >
        File
      </Button>
      <Menu
          anchorEl={this.state.anchorEl}
        anchorOrigin={{
          vertical: 'bottom',
          horizontal: 'right',
        }}
        transformOrigin={{
          vertical: 'top',
          horizontal: 'right',
        }}
        open={this.state.isOpenFile}
        onClose={()=> {
          this.setState({isOpenFile : false});
        }}
      >
        <MenuItem onClick={this.onOpenPLYandTXT} disableRipple>
          <span className="material-icons">folder_open</span>
          Open PLY and TXT.. (Ctrl+Shift+O)
        </MenuItem>
        <MenuItem onClick={this.onOpenProject} disableRipple>
          <span className="material-icons">file_open</span>
          Open Project.. (Ctrl+O)
        </MenuItem>

        <MenuItem onClick={this.onSaveProject} disableRipple>
          <span className="material-icons">save</span>
          Save Project.. (Ctrl+S)
        </MenuItem>

        <MenuItem onClick={this.onSaveAsProject} disableRipple>
          <span className="material-icons">save</span>
          Save As Project.. (Ctrl+Shift+S)
        </MenuItem>

        <Divider sx={{ my: 0.5 }} />
        <MenuItem onClick={() => {
          window.close();
        }} disableRipple>
          <span className="material-icons">close</span>
          Exit
        </MenuItem>
      </Menu>
    </div>);
  }
}


